Baseclass
=========

.. currentmodule:: chaospy

.. autosummary::
   :template: ndpoly.rst
   :toctree: ../../api

   ndpoly

.. autosummary::
   :toctree: ../../api

   ndpoly.coefficients
   ndpoly.dtype
   ndpoly.exponents
   ndpoly.indeterminants
   ndpoly.keys
   ndpoly.names
   ndpoly.values
   ndpoly.KEY_OFFSET
